@@ -2,6 +2,7 @@ package Alien::Build::Version::Basic;
 
 use strict;
 use warnings;
+use 5.008004;
 use Carp ();
 use base qw( Exporter );
 use overload
@@ -14,7 +15,7 @@ use overload
 our @EXPORT_OK = qw( version );
 
 # ABSTRACT: Very basic version object for Alien::Build
-our $VERSION = '2.26'; # VERSION
+our $VERSION = '2.40'; # VERSION
 
 
 sub new
@@ -71,7 +72,7 @@ Alien::Build::Version::Basic - Very basic version object for Alien::Build
 
 =head1 VERSION
 
-version 2.26
+version 2.40
 
 =head1 SYNOPSIS
 
@@ -236,6 +237,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
