@@ -18,7 +18,7 @@ use Config;
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic helper_ok interpolate_template_is );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '2.38'; # VERSION
+our $VERSION = '2.40'; # VERSION
 
 
 our @aliens;
@@ -131,6 +131,11 @@ sub run_ok
     $run->{fail} = 'command not found';
   }
 
+  unless(@aliens)
+  {
+    $ctx->diag("run_ok called without any aliens, you may want to call alien_ok");
+  }
+
   $ctx->release;
 
   $run;
@@ -193,7 +198,7 @@ sub xs_ok
   my @diag;
   my $dir = Alien::Build::Temp->newdir(
     TEMPLATE => 'test-alien-XXXXXX',
-    CLEANUP  => $^O =~ /^(MSWin32|cygwin)$/ ? 0 : 1,
+    CLEANUP  => $^O =~ /^(MSWin32|cygwin|msys)$/ ? 0 : 1,
   );
   my $xs_filename = path($dir)->child('test.xs')->stringify;
   my $c_filename  = path($dir)->child("test.@{[ $xs->{c_ext} ]}")->stringify;
@@ -262,6 +267,8 @@ sub xs_ok
     }
   }
 
+  push @diag, "xs_ok called without any aliens, you may want to call alien_ok" unless @aliens;
+
   if($ok)
   {
     my $cb = ExtUtils::CBuilder->new(
@@ -509,6 +516,11 @@ sub ffi_ok
     }
   }
 
+  unless(@aliens)
+  {
+    push @diag, 'ffi_ok called without any aliens, you may want to call alien_ok';
+  }
+
   if($ok)
   {
     $ffi = FFI::Platypus->new(
@@ -598,6 +610,7 @@ sub helper_ok
 
   my $ctx = context();
   $ctx->ok($ok, $message);
+  $ctx->diag("helper_ok called without any aliens, you may want to call alien_ok") unless @aliens;
   $ctx->release;
 
   $ok;
@@ -636,6 +649,7 @@ sub interpolate_template_is
 
   my $ctx = context();
   $ctx->ok($ok, $message, [@diag]);
+  $ctx->diag('interpolate_template_is called without any aliens, you may want to call alien_ok') unless @aliens;
   $ctx->release;
 
   $ok;
@@ -655,7 +669,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 2.38
+version 2.40
 
 =head1 SYNOPSIS
 
